﻿/*
 * UPF Parser and XML Exporter
 * 
 * written by Christian B. Mendl 2012
 * 
 * Reference: Quantum Espresso Unified Pseudopotential Format (UPF)
 * http://www.quantum-espresso.org/?page_id=269
 */

package ParseUPF;

import java.io.*;


class ParseUPF
{
	public static void main(String[] args)
	{
		if (args.length < 2)
		{
			System.out.println("Usage: ParseUPF file-in.upf file-out.xml");
			return;
		}

		if (!args[0].substring(args[0].lastIndexOf(".") + 1).equalsIgnoreCase("upf"))
		{
			System.out.println("'" + args[0] + "' does not appear to be a .upf file");
			return;
		}

		try
		{
			// Open the file that is the first command line parameter
			FileInputStream fstream = new FileInputStream(args[0]);
			DataInputStream in = new DataInputStream(fstream);
			BufferedReader reader = new BufferedReader(new InputStreamReader(in));

			Parser parser = new Parser();
			System.out.println("Parsing input file " + args[0] + "...");
			UPFData data = parser.ParseFile(reader);

			//Close the input stream
			in.close();
			System.out.println("Done");
	
			System.out.println("\nBasic information:");
			System.out.println("version number: " + data.header.n);
			System.out.println("element: " + data.header.psd);
			System.out.println("type: " + data.header.type);
			System.out.println("non-linear core correction: " + data.header.nlcc);
			System.out.println("Z valence: " + data.header.zp);
	
			System.out.println("\nExporting to XML file " + args[1] + "...");
			ExportXML exporter = new ExportXML();
			exporter.Export(data, args[1]);
			System.out.println("Done");
		}
		catch(FileNotFoundException e)
		{
			System.out.println("'" + args[0] + "' does not exist");
			e.printStackTrace();
		}
		catch(IOException e)
		{
			System.out.println(e.getMessage());
		}
	}
}
