/*
 * UPF Parser and XML Exporter
 * 
 * written by Christian B. Mendl 2012
 * 
 * Reference: Quantum Espresso Unified Pseudopotential Format (UPF)
 * http://www.quantum-espresso.org/?page_id=269
 */

package ParseUPF;

import java.util.ArrayList;


class UPFData
{
	enum OrbitalLabel { _1S, _2S, _2P, _3S, _3P, _3D, _4S, _4P, _4D, _4F, _5S, _5P, _5D, _5F, _5G };

	static class PPHeader
	{
		int n;			// version number
		String psd;		// element
		enum Type { US, NC, PAW };
		Type type;		// type
		boolean nlcc;	// nonlinear core correction

		static class ExchangeCorrelationFunctional
		{
			String exch;
			String correlations;
			String exchGradCorrection;
			String correlationsGradCorrection;
		};
		ExchangeCorrelationFunctional dft;

		double zp;		// Z valence
		double etotps;	// total pseudo-valence energy of the pseudopotential, should be equal to total valence for PAW
		double ecutwfc, ecutrho;		// suggested cut-off for wfc and rho
		int lmax;		// max angular momentum component
		int mesh;		// number of points in mesh
		int natwfc, nbeta;		// number of wavefunctions, projectors

		static class Wavefunction
		{
			OrbitalLabel els;
			int lchi;
			double oc;
		};
		ArrayList<Wavefunction> wavefunctions;
	};

	static class PPMesh
	{
		ArrayList<Double> r;
		ArrayList<Double> rab;
	};

	static class PPNLCC
	{
		ArrayList<Double> rho_atc;
	};

	static class PPLocal
	{
		ArrayList<Double> vloc;
	};

	static class PPNonLocal
	{
		static class PPBeta
		{
			int lll;
			int kkbeta;	// must be equal to beta.Count
			ArrayList<Double> beta;
		};

		ArrayList<PPBeta> betaList;

		double[][] D;
	};

	static class PPPSWFC
	{
		static class Wavefunction
		{
			OrbitalLabel els;
			int lchi;
			double oc;
			ArrayList<Double> chi;
		};
		ArrayList<Wavefunction> wavefunctions;
	};

	static class PPRhoAtom
	{
		ArrayList<Double> rho_at;
	};

	PPHeader   header;
	PPMesh     mesh;
	PPNLCC     nlcc;
	PPLocal    local;
	PPNonLocal nonLocal;
	PPPSWFC    pswfc;
	PPRhoAtom  rhoAtom;
}
